@@ -25,7 +25,9 @@ pub mod elixir;
 pub mod elm;
 pub mod env_var;
 pub mod erlang;
+pub mod fennel;
 pub mod fill;
+pub mod fossil_branch;
 pub mod gcloud;
 pub mod git_branch;
 pub mod git_commit;
@@ -33,6 +35,7 @@ pub mod git_metrics;
 pub mod git_state;
 pub mod git_status;
 pub mod go;
+pub mod gradle;
 pub mod guix_shell;
 pub mod haskell;
 pub mod haxe;
@@ -59,6 +62,7 @@ pub mod os;
 pub mod package;
 pub mod perl;
 pub mod php;
+pub mod pijul_channel;
 pub mod pulumi;
 pub mod purescript;
 pub mod python;
@@ -148,8 +152,12 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     erlang: erlang::ErlangConfig<'a>,
     #[serde(borrow)]
+    fennel: fennel::FennelConfig<'a>,
+    #[serde(borrow)]
     fill: fill::FillConfig<'a>,
     #[serde(borrow)]
+    fossil_branch: fossil_branch::FossilBranchConfig<'a>,
+    #[serde(borrow)]
     gcloud: gcloud::GcloudConfig<'a>,
     #[serde(borrow)]
     git_branch: git_branch::GitBranchConfig<'a>,
@@ -164,6 +172,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     golang: go::GoConfig<'a>,
     #[serde(borrow)]
+    gradle: gradle::GradleConfig<'a>,
+    #[serde(borrow)]
     guix_shell: guix_shell::GuixShellConfig<'a>,
     #[serde(borrow)]
     haskell: haskell::HaskellConfig<'a>,
@@ -215,6 +225,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     php: php::PhpConfig<'a>,
     #[serde(borrow)]
+    pijul_channel: pijul_channel::PijulConfig<'a>,
+    #[serde(borrow)]
     pulumi: pulumi::PulumiConfig<'a>,
     #[serde(borrow)]
     purescript: purescript::PureScriptConfig<'a>,
